@@ -102,8 +102,7 @@ def isDev():
     return sys.executable.endswith("python.exe")
 
 
-def create():
+def create(targetPath):
     currentFolder = os.path.dirname(__file__)
-    file = b.getPath(currentFolder, "data/task.zip")
-    print(file)
-    print(os.path.exists(file))
+    taskZipfile = b.getPath(currentFolder, "data/task.dat")
+    b.zipFileExtract(taskZipfile, targetPath)
